﻿
using System.Windows;
using Microsoft.Practices.Prism.MefExtensions;
using Microsoft.Practices.Prism.Modularity;
using System.ComponentModel.Composition.Hosting;
using PrismMEF1.Infrastructure;

namespace PrismMEF1
{
    /// <summary>
    /// 부트스트리퍼
    /// </summary>
    public class Bootstrapper : MefBootstrapper
    {
        /// <summary>
        /// 쉘 초기화
        /// </summary>
        protected override void InitializeShell()
        {
            base.InitializeShell();
            Application.Current.RootVisual = (UIElement)Shell;
        }


        protected override DependencyObject CreateShell()
        {
            //익스포트된 Shell.xaml를 임포트 시켜서 리턴
            return Container.GetExportedValue<Shell>();
        }

        /// <summary>
        /// 모든 MEF 콤포저블 카탈로그들이 들어가 있는 넘
        /// </summary>
        protected override void ConfigureAggregateCatalog()
        {
            base.ConfigureAggregateCatalog();

            //거기다가 이 프로젝트까지 카탈로그에 넣는데...왜 넣는걸까?
            AggregateCatalog.Catalogs.Add(new AssemblyCatalog(this.GetType().Assembly));
        }

        /// <summary>
        /// 모듈카탈로그를 만드는데 사용
        /// </summary>
        /// <returns></returns>
        protected override IModuleCatalog CreateModuleCatalog()
        {
            //모듈카탈로그 생성
            ModuleCatalog moduleCatalog = new ModuleCatalog();

            //ModuleName, Moduletype은 클래스 이름
            //즉시 다운로드
            moduleCatalog.AddModule
            (
                new ModuleInfo
                {
                    InitializationMode = InitializationMode.WhenAvailable,
                    Ref = "PrismMEF1.MainMenuModule.xap",
                    ModuleName = ModuleNames.MainMenuModuleImp,
                    ModuleType = "PrismMEF1.MainMenuModule.MainMenuModuleImp, PrismMEF1.MainMenuModule, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
                }
            );
            //다중에 다운로드
            moduleCatalog.AddModule
            (
                new ModuleInfo
                {
                    InitializationMode = InitializationMode.OnDemand,
                    Ref = "PrismMEF1.MDModule.xap",
                    ModuleName = ModuleNames.MDModuleImp,
                    ModuleType = "PrismMEF1.MDModule.MDModuleImp, PrismMEF1.MDModule, Version=1.0.0.0, Culture=neutral, PublicKeyToken=null"
                }
            );

            //추가한 모듈카탈로그를 반환해야징;;
            return moduleCatalog;
        }
    }
}
