﻿using System.ComponentModel.Composition;
using System.Windows.Controls;
using Microsoft.Practices.Prism.Modularity;
using PrismMEF1.Infrastructure;
using System;

namespace PrismMEF1
{
    [Export]
    public partial class Shell : UserControl
    {
        //모듈메니저
        IModuleManager _moduleManager;

        //임포트 컨트스트럭처
        [ImportingConstructor]
        public Shell([Import(AllowRecomposition = false)]IModuleManager moduleManager)
        {
            InitializeComponent();

            //모듈메니저 연결
            _moduleManager = moduleManager;

            //모듈 다운로딩 이벤트에 하나 연결
            _moduleManager.ModuleDownloadProgressChanged += new EventHandler<ModuleDownloadProgressChangedEventArgs>(moduleManager_ModuleDownloadProgressChanged);
            //모듈 로딩완료 이벤트에 하나 연결
            _moduleManager.LoadModuleCompleted += new EventHandler<LoadModuleCompletedEventArgs>(_moduleManager_LoadModuleCompleted);
        }

        /// <summary>
        /// 모듈 다운로드 완료 이벤트 처리
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void _moduleManager_LoadModuleCompleted(object sender, LoadModuleCompletedEventArgs e)
        {
            if (e.ModuleInfo.ModuleName == ModuleNames.MDModuleImp)
            {
                //완료가 되면 다운로드 버튼 클릭 못하게
                btnDownload.IsEnabled = false;
            }
        }

        /// <summary>
        /// 모듈 다운로드 프로그래스 이벤트 처리
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        void moduleManager_ModuleDownloadProgressChanged(object sender, ModuleDownloadProgressChangedEventArgs e)
        {
            //메인 메뉴가 아니면 나감
            if (e.ModuleInfo.ModuleName != ModuleNames.MainMenuModuleImp)
                return;

            //다운로드 퍼세트 표시
            progressBar.Value = e.ProgressPercentage;
        }

        /// <summary>
        /// 다운로드 버튼 클릭
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void Button_Click(object sender, System.Windows.RoutedEventArgs e)
        {
            //모듈 다운로드
            _moduleManager.LoadModule(ModuleNames.MDModuleImp);

        }
    }
}
